==> nextcloud-app-mail-1.10.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/da.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Fejl ved autodetektion. Anvend venligst manuel opsætning",
    "Updating account failed: " : "Kontoen blev ikke opdateret:",
    "Creating account failed: " : "Oprettelse af konto mislykkedes:",
    "Embedded message %s" : "Indlejret besked %s",
    "Mails" : "Mails",
    "Mail" : "Mail",
    "💌 A mail app for Nextcloud" : "💌 En mail app til Nextcloud",
    "Auto" : "Auto",
    "Name" : "Navn",
    "Mail Address" : "Email addresse",
    "Password" : "Kodeord",
    "Manual" : "Manuel",
    "IMAP Settings" : "IMAP opsætning",
    "IMAP Host" : "IMAP host",
    "IMAP Security" : "IMAP sikkerhed",
    "None" : "Ingen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP bruger",
    "IMAP Password" : "IMAP kodeord",
    "SMTP Settings" : "SMTP opsætnin",
    "SMTP Host" : "SMTP host",
    "SMTP Security" : "SMTP sikkerhed",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP bruger",
    "SMTP Password" : "SMTP kodeord",
    "Save" : "Gem",
    "Connect" : "Tilslut",
    "Account settings" : "Kontoindstillinger",
    "Signature" : "Underskrift",
    "Add mail account" : "Tilføj mail konto",
    "Use Gravatar and favicon avatars" : "Brug Gravatar og favicon avatarer",
    "Register as application for mail links" : "Registrer som program til at åbne mail links",
    "From" : "Fra",
    "Select account" : "Vælg konto",
    "To" : "Til",
    "Contact or email address …" : "Kontakt eller email…",
    "+ Cc/Bcc" : "+ Cc/Bcc",
    "Cc" : "Cc",
    "No contacts found." : "Ingen kontakter.",
    "Bcc" : "Bcc",
    "Subject" : "Emne",
    "Subject …" : "Emne…",
    "This message came from a noreply address so your reply will probably not be read." : "Denne meddelelse kom fra en svar-ikke adresse. Dit svar vil sansynligvis ikke blive læst. ",
    "The following recipients do not have a PGP key: {recipients}." : "Følgende modtagere har ikke en PGP nøgle: {recipients}.",
    "Write message …" : "Skriv en besked…",
    "Saving draft …" : "Gemmer kladde…",
    "Draft saved" : "Kladde gemt",
    "Upload attachment" : "Upload vedhæftning",
    "Add attachment from Files" : "Vedhæft fra filer",
    "Enable formatting" : "Aktiver formatering",
    "Encrypt message with Mailvelope" : "Kryptér meddelelse med Mailvelope",
    "Uploading attachments …" : "Uploader vedhæftninger",
    "Sending …" : "Sender ...",
    "Go back" : "Gå tilbage",
    "Retry" : "Prøv igen",
    "Message sent!" : "Beskeden blev sendt!",
    "Write another message" : "Skriv en ny besked…",
    "Send" : "Send",
    "Encrypt and send" : "Kryptér og send",
    "Send unencrypted" : "Send ukrypteret",
    "Uploading {percent}% …" : "Uploader {percent}%…",
    "Choose a file to add as attachment" : "Vælg en fil, der skal tilføjes som vedhæftning",
    "Choose a file to share as a link" : "Vælg en fil der skal deles som link",
    "Plain text" : "Klartekst",
    "Rich text" : "Formateret tekst",
    "No messages" : "Ingen beskeder",
    "Draft: " : "Kladde:",
    "Mark unread" : "Marker som ulæst",
    "Mark read" : "Marker som læst",
    "Unselect" : "Fravælg",
    "Select" : "Vælg",
    "Loading messages" : "Henter beskedder",
    "Choose" : "Vælg",
    "Favorites" : "Favoritter",
    "Other" : "Andet",
    "Reply" : "Besvar",
    "Forward" : "Videresend",
    "View source" : "Vis kildekode",
    "Message source" : "Beskedens kildekode",
    "Attachments" : "Vedhæftede filer",
    "Import into calendar" : "Importere til kalender",
    "Download attachment" : "Hent vedhæftning",
    "Save to Files" : "Gem til filer",
    "Unnamed" : "Unavngiven",
    "Embedded message" : "Indlejret besked",
    "Choose a folder to store the attachment in" : "Vælg den mappe, hvor vedhæftningen skal gemmes i",
    "Save all to Files" : "Gem alle filer",
    "Choose a folder to store the attachments in" : "Vælg den mappe, hvor vedhæftningerne skal gemmes i",
    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
    "Move" : "Flyt",
    "New message" : "Ny besked",
    "Settings" : "Indstillinger",
    "Quota" : "Kvote",
    "Saving" : "Gemmer",
    "Move down" : "Flyt ned",
    "Remove account" : "Fjern konto",
    "Loading …" : "Indlæser…",
    "Cancel" : "Annullér",
    "Mark all as read" : "Markér alle som læst",
    "Edit name" : "Rediger navn",
    "Clear cache" : "Ryd cache",
    "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
    "Not found" : "Ikke fundet",
    "Could not load your draft" : "Kladden kunne ikke indlæses",
    "Could not load original message" : "Den originale besked kunne ikke indlæses",
    "No message selected" : "Ingen besked valgt",
    "Delete" : "Slet",
    "Airplane" : "Fly",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Fly {flightNr} fra {depAirport} til {arrAirport}",
    "Train" : "Tog",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}",
    "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}",
    "General" : "Generelt",
    "IMAP" : "IMAP",
    "User" : "ruger",
    "Host" : "Vært",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Keyboard shortcut" : "Tastaturgenvej",
    "Keyboard shortcuts" : "Tastaturgenveje",
    "Speed up your Mail experience with these quick shortcuts." : "Gør brugen af Mail hurtige med disse genveje.",
    "Compose new message" : "Skriv en ny meddelelse",
    "Newer message" : "Nyere besked",
    "Older message" : "Ældre besked",
    "Toggle star" : "Toggle stjerne",
    "Toggle unread" : "Toggle læst",
    "Search" : "Søg",
    "Refresh" : "Opdatér",
    "Connect your mail account" : "Forbind din mail konto",
    "Unexpected error during account creation" : "Uventet fejl under oprettelse af konto",
    "All" : "Alle",
    "Archive" : "Arkivér",
    "Drafts" : "Udkast",
    "Priority inbox" : "Prioriteret indbakke",
    "All inboxes" : "Alle indbakker",
    "Inbox" : "Indbakke",
    "Junk" : "Junk",
    "Sent" : "Sendt",
    "Trash" : "Papirkurv",
    "Error while sharing file" : "Fejl ved deling af fil",
    "{from}\n{subject}" : "{fra}\n{emne}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny besked \nfra {from}","%n nye beskeder \nfra {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke hente {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Der var et problem med at hente {tag}{name}{endtag}",
    "Could not load your message" : "Din besked kunne ikke indlæses",
    "Could not load the desired message" : "Den ønskede besked kunne ikke indlæses",
    "Could not load the message" : "Beskeden kunne ikke indlæses",
    "Error loading message" : "Fejl under indlæsning af besked",
    "Forwarding to %s" : "Videre send til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
    "Redirect" : "Omdiriger",
    "The link leads to %s" : "Linket fører til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker at besøge denne side, kan du vende tilbage til <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Videre til %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-1.11.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/da.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Fejl ved autodetektion. Anvend venligst manuel opsætning",
    "Updating account failed: " : "Kontoen blev ikke opdateret:",
    "Creating account failed: " : "Oprettelse af konto mislykkedes:",
    "Embedded message %s" : "Indlejret besked %s",
    "Important mail" : "Vigtig mail",
    "Unread mail" : "Ulæst mail",
    "Important" : "Vigtig",
    "Work" : "Arbejde",
    "Personal" : "Personlig",
    "To Do" : "to do -liste",
    "Later" : "Senere",
    "Mails" : "Mails",
    "Mail" : "Mail",
    "💌 A mail app for Nextcloud" : "💌 En mail app til Nextcloud",
    "Drafts are saved in:" : "Kladder gemmes i:",
    "Sent messages are saved in:" : "Sendte meddelelser gemmes i:",
    "Deleted messages are moved in:" : "Slettede meddelelser flyttes ind:",
    "Auto" : "Auto",
    "Name" : "Navn",
    "Mail Address" : "Email addresse",
    "Password" : "Kodeord",
    "Manual" : "Manuel",
    "IMAP Settings" : "IMAP opsætning",
    "IMAP Host" : "IMAP host",
    "IMAP Security" : "IMAP sikkerhed",
    "None" : "Ingen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP bruger",
    "IMAP Password" : "IMAP kodeord",
    "SMTP Settings" : "SMTP opsætnin",
    "SMTP Host" : "SMTP host",
    "SMTP Security" : "SMTP sikkerhed",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP bruger",
    "SMTP Password" : "SMTP kodeord",
    "Save" : "Gem",
    "Connect" : "Tilslut",
    "Account settings" : "Kontoindstillinger",
    "Change name" : "Ændre navn",
    "Signature" : "Underskrift",
    "A signature is added to the text of new messages and replies." : "En signatur tilføjes til teksten i nye meddelelser og svar.",
    "Writing mode" : "Skrivemåde",
    "Preferred writing mode for new messages and replies." : "Foretrukken skrivemåde for nye meddelelser og svar.",
    "Default folders" : "Standardmapper",
    "The folders to use for drafts, sent messages and deleted messages." : "De mapper, der skal bruges til kladder, sendte beskeder og slettede meddelelser.",
    "Mail server" : "Mail server",
    "Sieve filter server" : "Sigt filter server",
    "Cancel" : "Annullér",
    "Add mail account" : "Tilføj mail konto",
    "Use Gravatar and favicon avatars" : "Brug Gravatar og favicon avatarer",
    "Register as application for mail links" : "Registrer som program til at åbne mail links",
    "Show keyboard shortcuts" : "Vis tastaturgenveje",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillad, at appen indsamler data om dine interaktioner. Baseret på disse data vil appen tilpasse sig dine præferencer. Dataene gemmes kun lokalt.",
    "Put my text to the bottom of a reply instead of on top of it." : "Sæt min tekst til bunden af et svar i stedet for oven på den.",
    "Automatically classify importance of new email" : "Klassificer automatisk vigtigheden af ny e -mail",
    "Could not update preference" : "Præference kunne ikke opdateres",
    "From" : "Fra",
    "Select account" : "Vælg konto",
    "To" : "Til",
    "Contact or email address …" : "Kontakt eller email…",
    "+ Cc/Bcc" : "+ Cc/Bcc",
    "Cc" : "Cc",
    "No contacts found." : "Ingen kontakter.",
    "Bcc" : "Bcc",
    "Subject" : "Emne",
    "Subject …" : "Emne…",
    "This message came from a noreply address so your reply will probably not be read." : "Denne meddelelse kom fra en svar-ikke adresse. Dit svar vil sansynligvis ikke blive læst. ",
    "The following recipients do not have a PGP key: {recipients}." : "Følgende modtagere har ikke en PGP nøgle: {recipients}.",
    "Write message …" : "Skriv en besked…",
    "Cannot save draft because this account does not have a drafts mailbox configured." : "Kladden kan ikke gemmes, fordi der ikke er konfigureret en postkasse til udkast til denne konto.",
    "Saving draft …" : "Gemmer kladde…",
    "Draft saved" : "Kladde gemt",
    "Upload attachment" : "Upload vedhæftning",
    "Add attachment from Files" : "Vedhæft fra filer",
    "Enable formatting" : "Aktiver formatering",
    "Request a read receipt" : "Anmod om en læsekvittering",
    "Encrypt message with Mailvelope" : "Kryptér meddelelse med Mailvelope",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Leder du efter en måde at kryptere dine e -mails på? Installer Mailvelope -browserudvidelsen!",
    "Uploading attachments …" : "Uploader vedhæftninger",
    "Sending …" : "Sender ...",
    "Error sending your message" : "Fejl ved afsendelse af din besked",
    "Go back" : "Gå tilbage",
    "Retry" : "Prøv igen",
    "Warning sending your message" : "Advarsel om at sende din besked",
    "Send anyway" : "Send alligevel",
    "Message sent!" : "Beskeden blev sendt!",
    "Write another message" : "Skriv en ny besked…",
    "Add share link from {productName} Files" : "Tilføj delingslink fra {productName} filer",
    "Send" : "Send",
    "Encrypt and send" : "Kryptér og send",
    "Send unencrypted" : "Send ukrypteret",
    "Message {id} could not be found" : "Beskeden {id} kunne ikke findes",
    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postkasse konfigureret. Vælg en i kontoindstillingerne.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver at sende til mange modtagere i Til og/eller Cc. Overvej at bruge Bcc til at skjule modtageradresser.",
    "Uploading {percent}% …" : "Uploader {percent}%…",
    "Choose a file to add as attachment" : "Vælg en fil, der skal tilføjes som vedhæftning",
    "Choose a file to share as a link" : "Vælg en fil der skal deles som link",
    "Set up an account" : "Opret en konto",
    "Plain text" : "Klartekst",
    "Rich text" : "Formateret tekst",
    "No messages in this mailbox" : "Ingen beskeder i denne postkasse",
    "No messages" : "Ingen beskeder",
    "Draft: " : "Kladde:",
    "Mark unimportant" : "Marker ikke vigtig",
    "Mark important" : "Marker som vigtig",
    "Mark unfavorite" : "Marker ikke favorit",
    "Mark favorite" : "Marker som favorit",
    "Mark unread" : "Marker som ulæst",
    "Mark read" : "Marker som læst",
    "Unselect" : "Fravælg",
    "Select" : "Vælg",
    "Loading messages" : "Henter beskedder",
    "Choose" : "Vælg",
    "Favorites" : "Favoritter",
    "Other" : "Andet",
    "Reply" : "Besvar",
    "Forward" : "Videresend",
    "View source" : "Vis kildekode",
    "Message source" : "Beskedens kildekode",
    "Import into calendar" : "Importere til kalender",
    "Download attachment" : "Hent vedhæftning",
    "Save to Files" : "Gem til filer",
    "Unnamed" : "Unavngiven",
    "Embedded message" : "Indlejret besked",
    "Choose a folder to store the attachment in" : "Vælg den mappe, hvor vedhæftningen skal gemmes i",
    "Save all to Files" : "Gem alle filer",
    "Choose a folder to store the attachments in" : "Vælg den mappe, hvor vedhæftningerne skal gemmes i",
    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
    "Move" : "Flyt",
    "New message" : "Ny besked",
    "Settings" : "Indstillinger",
    "Quota" : "Kvote",
    "Saving" : "Gemmer",
    "Move down" : "Flyt ned",
    "Remove account" : "Fjern konto",
    "Loading …" : "Indlæser…",
    "Mark all as read" : "Markér alle som læst",
    "Edit name" : "Rediger navn",
    "Clear cache" : "Ryd cache",
    "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
    "Not found" : "Ikke fundet",
    "Could not load your draft" : "Kladden kunne ikke indlæses",
    "Could not load original message" : "Den originale besked kunne ikke indlæses",
    "No message selected" : "Ingen besked valgt",
    "Delete" : "Slet",
    "Airplane" : "Fly",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Fly {flightNr} fra {depAirport} til {arrAirport}",
    "Train" : "Tog",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}",
    "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}",
    "General" : "Generelt",
    "IMAP" : "IMAP",
    "User" : "ruger",
    "Host" : "Vært",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Keyboard shortcut" : "Tastaturgenvej",
    "Keyboard shortcuts" : "Tastaturgenveje",
    "Speed up your Mail experience with these quick shortcuts." : "Gør brugen af Mail hurtige med disse genveje.",
    "Compose new message" : "Skriv en ny meddelelse",
    "Newer message" : "Nyere besked",
    "Older message" : "Ældre besked",
    "Toggle star" : "Toggle stjerne",
    "Toggle unread" : "Toggle læst",
    "Search" : "Søg",
    "Refresh" : "Opdatér",
    "Connect your mail account" : "Forbind din mail konto",
    "Unexpected error during account creation" : "Uventet fejl under oprettelse af konto",
    "All" : "Alle",
    "Archive" : "Arkivér",
    "Drafts" : "Udkast",
    "Priority inbox" : "Prioriteret indbakke",
    "All inboxes" : "Alle indbakker",
    "Inbox" : "Indbakke",
    "Junk" : "Junk",
    "Sent" : "Sendt",
    "Trash" : "Papirkurv",
    "Error while sharing file" : "Fejl ved deling af fil",
    "{from}\n{subject}" : "{fra}\n{emne}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny besked \nfra {from}","%n nye beskeder \nfra {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke hente {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Der var et problem med at hente {tag}{name}{endtag}",
    "Could not load your message" : "Din besked kunne ikke indlæses",
    "Could not load the desired message" : "Den ønskede besked kunne ikke indlæses",
    "Could not load the message" : "Beskeden kunne ikke indlæses",
    "Error loading message" : "Fejl under indlæsning af besked",
    "Forwarding to %s" : "Videre send til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
    "Redirect" : "Omdiriger",
    "The link leads to %s" : "Linket fører til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker at besøge denne side, kan du vende tilbage til <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Videre til %s"
},
"nplurals=2; plural=(n != 1);");
